translate.convert.ini2po.ini2po

Package translate :: Package convert :: Module ini2po :: Class ini2po |
[hide private]
[frames] | no frames]

# Class ini2po

source code

convert a .ini file to a .po file for handling the translation...

Instance Methods | [hide private]
convert_store(self, input_store, duplicatestyle="msgctxt") converts a .ini file to a .po file... | source code
merge_store(self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt") converts two .ini files to a .po file... | source code
convert_unit(self, input_unit, commenttype) Converts a .ini unit to a .po unit. | source code

Method Details | [hide private]

### convert_unit(self, input_unit, commenttype) | source code
Converts a .ini unit to a .po unit. Returns None if empty or not for translation.